@@ -37,9 +37,10 @@ Not suitable for data transfer between machines of different type.\n\
 
   if (nargin == 2)
     {
-      int fid = octave_stream_list::get_file_number (args(0));
+      int fid = OCTAVE__INTERPRETER__STREAM_LIST__GET_FILE_NUMBER (args(0));
 
-      octave_stream octs = octave_stream_list::lookup (fid, "fsave");
+      OCTAVE__STREAM octs = OCTAVE__INTERPRETER__STREAM_LIST__LOOKUP
+        (fid, "fsave");
       std::ostream *os = octs.output_stream ();
 
       octave_value val = args(1);
