@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2015, 2016 Olaf Till <i7tiol@t-online.de>
+Copyright (C) 2015-2017 Olaf Till <i7tiol@t-online.de>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -81,7 +81,7 @@ static int parse_tpasswd_line (char *line, int nread,
 
   if (! (p = strchr (line, ':')))
     {
-      c_verror ("invalid line in password file\n");
+      _p_error ("invalid line in password file\n");
 
       return -1;
     }
@@ -93,22 +93,27 @@ static int parse_tpasswd_line (char *line, int nread,
       // get verifier
       if (++pos >= nread)
         {
-          c_verror ("invalid line in password file\n");
+          _p_error ("invalid line in password file\n");
 
           return -1;
         }
       if (! (p = strchr (line = p + 1, ':')))
         {
-          c_verror ("invalid line in password file\n");
+          _p_error ("invalid line in password file\n");
 
           return -1;
         }
       // base64decode verifier
       b64entry.data = (unsigned char *) line;
       pos += (b64entry.size = p - line) + 1;
+
+#ifdef HAVE_GNUTLS_SRP_BASE64_DECODE2
+      if (gnutls_srp_base64_decode2 (&b64entry, verifier))
+#else
       if (gnutls_srp_base64_decode_alloc (&b64entry, verifier))
+#endif
         {
-          c_verror ("could not base64-decode verifier\n");
+          _p_error ("could not base64-decode verifier\n");
 
           return -1;
         }
@@ -116,22 +121,26 @@ static int parse_tpasswd_line (char *line, int nread,
       // get salt
       if (pos >= nread)
         {
-          c_verror ("invalid line in password file\n");
+          _p_error ("invalid line in password file\n");
 
           return -1;
         }
       if (! (p = strchr (line = p + 1, ':')))
         {
-          c_verror ("invalid line in password file\n");
+          _p_error ("invalid line in password file\n");
 
           return -1;
         }
       // base64decode salt
       b64entry.data = (unsigned char *) line;
       pos += (b64entry.size = p - line) + 1;
+#ifdef HAVE_GNUTLS_SRP_BASE64_DECODE2
+      if (gnutls_srp_base64_decode2 (&b64entry, salt))
+#else
       if (gnutls_srp_base64_decode_alloc (&b64entry, salt))
+#endif
         {
-          c_verror ("could not base64-decode salt\n");
+          _p_error ("could not base64-decode salt\n");
 
           return -1;
         }
@@ -139,13 +148,13 @@ static int parse_tpasswd_line (char *line, int nread,
       // check index
       if (pos >= nread)
         {
-          c_verror ("invalid line in password file\n");
+          _p_error ("invalid line in password file\n");
 
           return -1;
         }
       if (atoi (p + 1) != 1)
         {
-          c_verror ("invalid index in password file\n");
+          _p_error ("invalid index in password file\n");
 
           return -1;
         }
@@ -183,7 +192,7 @@ int octave_parallel_server_credentials_callback
 
   if (! passwd)
     {
-      c_verror ("no password file initialized\n");
+      _p_error ("no password file initialized\n");
 
       return -1;
     }
@@ -200,7 +209,7 @@ int octave_parallel_server_credentials_callback
 
   if (! line)
     {
-      c_verror ("could not allocate memory to read lines of password file\n");
+      _p_error ("could not allocate memory to read lines of password file\n");
 
       return -1;
     }
@@ -212,7 +221,7 @@ int octave_parallel_server_credentials_callback
 
   if (! spi.good ())
     {
-      c_verror ("could not open password file\n");
+      _p_error ("could not open password file\n");
 
       return -1;
     }
@@ -233,14 +242,14 @@ int octave_parallel_server_credentials_callback
       if (spi.get_istream ().fail ())
         {
           if (nread == BUFLEN - 1)
-            c_verror ("line in password file too long\n");
+            _p_error ("line in password file too long\n");
             
           break;
         }
 
       if (nread == 0)
         {
-          c_verror ("empty line in password file\n");
+          _p_error ("empty line in password file\n");
 
           break;
         }
