@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2016 Olaf Till <i7tiol@t-online.de
+Copyright (C) 2016-2018 Olaf Till <i7tiol@t-online.de
 
 This program is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free Software
@@ -21,11 +21,13 @@ this program; if not, see <http://www.gnu.org/licenses/>.
 
 #include <octave/load-save.h>
 
+#include "config.h"
+
 int minimal_read_header (std::istream& is, bool& swap,
-                         oct_mach_info::float_format& flt_fmt);
+                         OCTAVE__MACH_INFO::float_format& flt_fmt);
 
 int minimal_read_data (std::istream& is, octave_value& val,
-                       bool swap, oct_mach_info::float_format flt_fmt);
+                       bool swap, OCTAVE__MACH_INFO::float_format flt_fmt);
 
 void minimal_write_header (std::ostream& os);
 
