@@ -1,7 +1,6 @@
 /*
 
-Copyright (C) 2002 Hayato Fujiwara <h_fujiwara@users.sourceforge.net>
-Copyright (C) 2010-2015 Olaf Till <i7tiol@t-online.de>
+Copyright (C) 2010-2018 Olaf Till <i7tiol@t-online.de>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -22,19 +21,9 @@ along with this program; If not, see <http://www.gnu.org/licenses/>.
 // PKG_DEL: autoload ("network_set", "parallel_interface.oct", "remove");
 
 #include <octave/oct.h>
-
-#include "defun-dld.h"
-#include "dirfns.h"
-#include "error.h"
-#include "help.h"
-#include "oct-map.h"
-// #include "systime.h"
-#include "ov.h"
-#include "oct-obj.h"
-#include "utils.h"
-#include "oct-env.h"
-
-#include "parallel-gnutls.h"
+#include <octave/dirfns.h>
+#include <octave/oct-map.h>
+#include <octave/oct-env.h>
 
 #include <stdio.h>
 #include <sys/types.h>
@@ -46,6 +35,8 @@ along with this program; If not, see <http://www.gnu.org/licenses/>.
 #include <netdb.h>
 #include <unistd.h>
 
+#include "parallel-gnutls.h"
+
 DEFUN_DLD (network_set, args, ,
            "-*- texinfo -*-\n\
 @deftypefn {Loadable Function} {} network_set (@var{connections}, @var{key}, @var{val})\n\
@@ -98,35 +89,36 @@ not specified.\n\
       return retval;
     }
 
-  std::string key = args(1).string_value ();
-  if (error_state)
+  std::string key;
+
+  CHECK_ERROR (key = args(1).string_value (), retval,
+               "%s: second argument must be a string", fname.c_str ());
+
+  int arg;
+
+  if (! key.compare ("nlocaljobs"))
     {
-      error ("%s: second argument must be a string", fname.c_str ());
+      CHECK_ERROR (arg = args(2).int_value (), retval,
+                   "%s: argument for key 'nlocaljobs' could not be converted to a non-negative integer",
+                   fname.c_str ());
+
+      if (arg < 0)
+        {
+          error ("%s: argument for key 'nlocaljobs' could not be converted to a non-negative integer",
+                 fname.c_str ());
+
+          return retval;
+        }
+    }
+  else
+    {
+      error ("%s: key '%s' not recognized", fname.c_str (), key.c_str ());
 
       return retval;
     }
 
   for (int i = 0; i < nconns; i++)
-    {
-      if (! key.compare ("nlocaljobs"))
-        {
-          int arg = args(2).int_value ();
-          if (error_state || arg < 0)
-            {
-              error ("%s: argument for key 'nlocaljobs' could not be converted to a non-negative integer",
-                     fname.c_str ());
-
-              return retval;
-            }
-          conns->get_connections ()(i)->set_nlocaljobs (arg);
-        }
-      else
-        {
-          error ("%s: key '%s' not recognized", fname.c_str (), key.c_str ());
-
-          return retval;
-        }
-    }
+    conns->get_connections ()(i)->set_nlocaljobs (arg);
 
   return retval;
 }
