@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2015, 2016 Olaf Till <i7tiol@t-online.de>
+Copyright (C) 2015-2018 Olaf Till <i7tiol@t-online.de>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,12 +17,13 @@ along with this program; If not, see <http://www.gnu.org/licenses/>.
 
 */
 
-#include "parallel-gnutls.h"
-
+#include <octave/oct.h>
 #include <octave/Array.cc>
 
 #include <sys/poll.h>
 
+#include "parallel-gnutls.h"
+
 NO_INSTANTIATE_ARRAY_SORT (octave_parallel_connection *);
 
 INSTANTIATE_ARRAY (octave_parallel_connection *, OCTAVE_API);
@@ -52,28 +53,28 @@ int octave_parallel_connection::wait_for_errors_or_data (void)
 {
   if (! cmd_stream)
     {
-      c_verror ("can't poll since no command stream present");
+      _p_error ("can't poll since no command stream present");
 
       return -1;
     }
 
   if (! data_stream)
     {
-      c_verror ("can't poll since no data stream present");
+      _p_error ("can't poll since no data stream present");
 
       return -1;
     }
 
   if (! cmd_stream->get_strbuf ()->good ())
     {
-      c_verror ("can't poll since command stream not good");
+      _p_error ("can't poll since command stream not good");
 
       return -1;
     }
 
   if (! data_stream->get_strbuf ()->good ())
     {
-      c_verror ("can't poll since data stream not good");
+      _p_error ("can't poll since data stream not good");
 
       return -1;
     }
@@ -91,7 +92,7 @@ int octave_parallel_connection::wait_for_errors_or_data (void)
   // block until something is readable
   if (poll (pfd, 2, -1) == -1)
     {
-      c_verror ("error in poll()");
+      _p_error ("error in poll()");
 
       return (-1);
     }
@@ -109,7 +110,7 @@ DEFINE_OV_TYPEID_FUNCTIONS_AND_DATA (octave_parallel_connections,
 octave_value octave_parallel_connections::do_index_op
 (const octave_value_list& idx, bool resize_ok)
 {
-  octave_value_list err_retval;
+  octave_value err_retval;
 
   octave_idx_type n_idx = idx.length ();
 
@@ -144,7 +145,7 @@ octave_value octave_parallel_connections::do_index_op
             return err_retval;
           }
         octave_idx_type len = i.length ();
-        if (i.is_vector ())
+        if (i.IDXVECTOR_ISVECTOR ())
           {
             if (i.sorted (true).length () < len)
               {
