@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2015, 2016 Olaf Till <i7tiol@t-online.de>
+Copyright (C) 2015-2018 Olaf Till <i7tiol@t-online.de>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -21,15 +21,16 @@ along with this program; If not, see <http://www.gnu.org/licenses/>.
 
 #define __OCT_PARALLEL_CONNECTION__
 
+#include <octave/oct.h>
+#include <octave/oct-refcount.h>
+
 #include <fstream>
 #include <string.h>
 
-#include <octave/oct-refcount.h>
+#include "minimal-load-save.h"
 
 #include "p-streams.h"
 
-#include "minimal-load-save.h"
-
 // at 'p' 37 bytes must be available; returns 0 on success and -1 on failure
 int oct_parallel_store_unique_identifier (char *p);
 
@@ -47,19 +48,21 @@ public:
 
   octave_parallel_connection (const char *arg_peer_name, bool i_am_server,
                               const char *auuid)
-    : cmd_stream (NULL), data_stream (NULL), peer_name (arg_peer_name),
-      server (i_am_server), connection_open (false), uuid (auuid),
-      pseudo_connection (false), peer_node_n (-1), nproc (0),
-      nlocaljobs (0)
+    : peer_node_n (-1), cmd_stream (NULL), data_stream (NULL),
+      connection_open (false), pseudo_connection (false),
+      peer_name (arg_peer_name), nproc (0), nlocaljobs (0),
+      server (i_am_server), uuid (auuid)
   {
 
   }
 
   octave_parallel_connection (bool i_am_server, const char *auuid)
-    : cmd_stream (NULL), data_stream (NULL), peer_name (""),
-      server (i_am_server), connection_open (false), uuid (auuid),
-      pseudo_connection (true), peer_node_n (-1), nproc (0),
-      nlocaljobs (0)
+    : peer_node_n (-1), cmd_stream (NULL), data_stream (NULL),
+      connection_open (false), pseudo_connection (true),
+      peer_name (""), nproc (0), nlocaljobs (0),
+      server (i_am_server), uuid (auuid)
+      
+      
   {
 
   }
@@ -116,14 +119,14 @@ public:
   {
     if (! cmd_stream)
       {
-        c_verror ("can't poll since no command stream present");
+        _p_error ("can't poll since no command stream present");
 
         return -1;
       }
 
     if (! cmd_stream->get_strbuf ()-> good ())
       {
-        c_verror ("can't poll since command stream not good");
+        _p_error ("can't poll since command stream not good");
 
         return -1;
       }
@@ -137,12 +140,12 @@ public:
 
         if (! cmd_stream->good ())
           {
-            c_verror ("error in reading error code");
+            _p_error ("error in reading error code");
 
             return -1;
           }
 
-        c_verror ("An error with code %u occurred in server %s.\nSee %s:/tmp/octave_error-<remote-host-name>_%s.log for details.",
+        _p_error ("An error with code %u occurred in server %s.\nSee %s:/tmp/octave_error-<remote-host-name>_%s.log for details.",
                err, peer_name.c_str (), peer_name.c_str (), uuid.c_str ());
 
         ret = 1;
@@ -185,7 +188,7 @@ public:
 
         if (! data_stream->good ())
           {
-            c_verror ("could not close data stream");
+            _p_error ("could not close data stream");
 
             return -1;
           }
@@ -215,7 +218,7 @@ public:
                     if (fcntl (cmd_stream->get_strbuf ()->get_fid (),
                                F_SETFL, O_NONBLOCK))
                       {
-                        c_verror ("tried to switch to non-blocking mode due to undefined connection state, but it did not work; not sending close command");
+                        _p_error ("tried to switch to non-blocking mode due to undefined connection state, but it did not work; not sending close command");
                         send_close_cmd = false;
                       }
                   }
@@ -231,7 +234,7 @@ public:
 
             if (! cmd_stream->good ())
               {
-                c_verror ("could not close command stream");
+                _p_error ("could not close command stream");
 
                 ret = -1;
               }
@@ -243,7 +246,7 @@ public:
 
             if (! data_stream->good ())
               {
-                c_verror ("could not close data stream");
+                _p_error ("could not close data stream");
 
                 ret = -1;
               }
@@ -255,7 +258,7 @@ public:
       }
     else if (! pseudo_connection)
       {
-        c_verror ("connection is not open");
+        _p_error ("connection is not open");
 
         return -1;
       }
@@ -273,8 +276,6 @@ public:
     return server;
   }
 
-  int32_t peer_node_n; // -1 is unset, 0 is client
-
   int connection_read_header (void)
   {
     return minimal_read_header (data_stream->get_istream (),
@@ -297,6 +298,8 @@ public:
     return uuid;
   }
 
+  int32_t peer_node_n; // -1 is unset, 0 is client
+
 private:
 
   octave_parallel_stream *cmd_stream;
@@ -330,7 +333,7 @@ private:
   // for Octaves save and load functions
   bool global;
   bool swap;
-  oct_mach_info::float_format flt_fmt;
+  OCTAVE__MACH_INFO::float_format flt_fmt;
   std::string doc;
 };
 
@@ -347,8 +350,7 @@ public:
   }
 
   octave_parallel_network (int n)
-  : refcount (0), closed (false),
-    connections (dim_vector (n, 1), NULL)
+    : connections (dim_vector (n, 1), NULL), refcount (0), closed (false)
   {
 
   }
@@ -379,7 +381,7 @@ public:
   {
     if (closed)
       {
-        c_verror ("network already closed");
+        _p_error ("network already closed");
 
         return -1;
       }
@@ -392,7 +394,7 @@ public:
             ret = -1;
 
         if (ret)
-          c_verror ("could not close network");
+          _p_error ("could not close network");
         else
           closed = true;
 
@@ -436,7 +438,7 @@ private:
 
   connarray connections;
 
-  octave_refcount<int> refcount;
+  OCTAVE__REFCOUNT<int> refcount;
 
   bool closed;
 };
@@ -455,8 +457,8 @@ public:
 
   octave_parallel_connections_rep (octave_parallel_network *net,
                                    const char *auuid, bool i_am_server)
-    : network (net), uuid (auuid), server (i_am_server),
-    connections (net->get_ref ()), indexed (false)
+    : network (net), connections (net->get_ref ()), uuid (auuid),
+      server (i_am_server), indexed (false)
   {
     subnet = connections;
   }
@@ -465,8 +467,8 @@ public:
   octave_parallel_connections_rep (octave_parallel_network *net,
                                    const char *auuid, bool i_am_server,
                                    octave_parallel_network::connarray &asubnet)
-    : network (net), uuid (auuid), server (i_am_server),
-    connections (net->get_ref ()), indexed (true)
+    : network (net), connections (net->get_ref ()), uuid (auuid),
+      server (i_am_server), indexed (true)
   {
     subnet = asubnet;
   }
