@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2015, 2016 Olaf Till <i7tiol@t-online.de>
+Copyright (C) 2015-2018 Olaf Till <i7tiol@t-online.de>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -87,7 +87,7 @@ octave_parallel_streambuf : public std::streambuf
 public:
 
   octave_parallel_streambuf (void)
-  : fid (-1), store_errno (0), readable (false), writeable (false)
+    : readable (false), writeable (false), fid (-1), store_errno (0)
   {
     // no character in the one-character-wide buffer at the beginning
     setg (&inbuf, (&inbuf) + 1, (&inbuf) + 1);
@@ -137,8 +137,6 @@ public:
     if (count == 0)
       return 0; // if nothing needs to be written, there's no need to
                 // risk write() still being interrupted by a signal
-    else if (count < 0)
-      return -1;
 
     ssize_t ret;
 
@@ -187,8 +185,6 @@ public:
 
     if (count == 0)
       return 0;
-    else if (count < 0)
-      return -1;
 
     int ndiff = 0;
     if (gptr () != egptr ())
@@ -373,7 +369,7 @@ public:
       return -1;
   }
 
-  int network_recv_string (char *s, int maxl)
+  int network_recv_string (char *s, uint32_t maxl)
   {
     uint32_t l, t;
 
@@ -386,7 +382,7 @@ public:
 
     if (l > maxl - 1)
       {
-        c_verror ("string to be received would be longer than buffer");
+        _p_error ("string to be received would be longer than buffer");
 
         return -1;
       }
@@ -483,8 +479,6 @@ private:
     if (count == 0)
       return 0; // if nothing needs to be written, there's no need to
                 // risk read() still being interrupted by a signal
-    else if (count < 0)
-      return -1;
 
     ssize_t ret;
 
@@ -527,7 +521,7 @@ private:
 
     if (first_time)
       {
-        c_verror ("This machine doesn't seem to use twos complement as negative integer representation. If you want this to be supported, please file a bug report.");
+        _p_error ("This machine doesn't seem to use twos complement as negative integer representation. If you want this to be supported, please file a bug report.");
 
         first_time = false;
       }
@@ -802,7 +796,7 @@ octave_parallel_gnutls_srp_server_credentials :
 public:
 
   octave_parallel_gnutls_srp_server_credentials
-  (std::string passwd_file)
+  (std::string &passwd_file)
   {
     if (! gnutls_srp_allocate_server_credentials
         ((gnutls_srp_server_credentials_t *) &cred))
