@@ -1,7 +1,7 @@
 /*
 
 Copyright (C) 2002 Hayato Fujiwara <h_fujiwara@users.sourceforge.net>
-Copyright (C) 2010-2016 Olaf Till <i7tiol@t-online.de.de>
+Copyright (C) 2010-2018 Olaf Till <i7tiol@t-online.de.de>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -21,9 +21,10 @@ along with this program; If not, see <http://www.gnu.org/licenses/>.
 // PKG_ADD: autoload ("pconnect", "parallel_interface.oct");
 // PKG_DEL: autoload ("pconnect", "parallel_interface.oct", "remove");
 
+#include <octave/oct.h>
+
 #include "config.h"
 
-#include <octave/oct.h>
 #include <octave/oct-env.h>
 
 #include <sys/socket.h>
@@ -40,7 +41,7 @@ along with this program; If not, see <http://www.gnu.org/licenses/>.
 static
 int assert_file (std::string &path)
 {
-  file_stat stat (path);
+  OCTAVE__SYS__FILE_STAT stat (path);
 
   if (! stat.is_reg ())
     return -1;
@@ -348,25 +349,32 @@ sclose (sockets);\n\
         {
           if (! cpfile.length ())
             {
+#ifdef HAVE_OCTAVE_CONFIG_FCNS
+              std::string octave_home = octave::config::octave_home ();
+#else
               extern std::string Voctave_home;
-              cpfile = Voctave_home + file_ops::dir_sep_str () + "share" +
-                file_ops::dir_sep_str () + "octave" + file_ops::dir_sep_str () +
-                "parallel-srp-data" + file_ops::dir_sep_str () + "client" +
-                file_ops::dir_sep_str () + "user_passwd";
+              std::string octave_home = Voctave_home;
+#endif
+              cpfile = octave_home + OCTAVE__SYS__FILE_OPS::dir_sep_str () +
+                "share" + OCTAVE__SYS__FILE_OPS::dir_sep_str () + "octave" +
+                OCTAVE__SYS__FILE_OPS::dir_sep_str () + "parallel-srp-data" +
+                OCTAVE__SYS__FILE_OPS::dir_sep_str () + "client" +
+                OCTAVE__SYS__FILE_OPS::dir_sep_str () + "user_passwd";
               if (assert_file (cpfile))
                 {
                   octave_value_list f_args (1);
                   f_args(0) = octave_value ("prefix");
                   octave_value_list f_ret;
-                  CHECK_ERROR (f_ret = feval ("pkg", f_args, 1), retval,
+                  CHECK_ERROR (f_ret = OCTAVE__FEVAL ("pkg", f_args, 1), retval,
                                "%s: could not get prefix from pkg",
                                fname.c_str ());
                   CHECK_ERROR (cpfile = f_ret(0).string_value (), retval,
                                "%s: could not convert output of pkg ('prefix') to string)",
                                fname.c_str ());
-                  cpfile = cpfile + file_ops::dir_sep_str () +
-                    "parallel-srp-data" + file_ops::dir_sep_str () +
-                    "client" + file_ops::dir_sep_str () + "user_passwd";
+                  cpfile = cpfile + OCTAVE__SYS__FILE_OPS::dir_sep_str () +
+                    "parallel-srp-data" +
+                    OCTAVE__SYS__FILE_OPS::dir_sep_str () + "client" +
+                    OCTAVE__SYS__FILE_OPS::dir_sep_str () + "user_passwd";
                   if (assert_file (cpfile))
                     {
                       error ("%s: no regular file found at default password file paths",
@@ -463,7 +471,7 @@ sclose (sockets);\n\
             break;
           else if (errno != ECONNREFUSED && errno != EINTR)
             {
-              c_verror ("connect error");
+              _p_error ("connect error");
               break;
             }
           else
@@ -670,7 +678,7 @@ sclose (sockets);\n\
             }
           else if (errno != ECONNREFUSED && errno != EINTR)
             {
-              c_verror ("connect error");
+              _p_error ("connect error");
               break;
             }
           else
