@@ -1,6 +1,6 @@
 // Copyright (C) 2002 Hayato Fujiwara <h_fujiwara@users.sourceforge.net>
 
-// Copyright (C) 2010-2016 Olaf Till <i7tiol@t-online.de>
+// Copyright (C) 2010-2018 Olaf Till <i7tiol@t-online.de>
 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -23,8 +23,6 @@
 #include <octave/ls-oct-binary.h>
 #include <octave/oct-stream.h>
 
-#include "parallel-gnutls.h"
-
 #include <sys/socket.h>
 #include <sys/poll.h>
 #include <netinet/in.h>
@@ -34,6 +32,8 @@
 #include <unistd.h>
 #endif
 
+#include "parallel-gnutls.h"
+
 DEFUN_DLD (psend, args, ,
            "-*- texinfo -*-\n\
 @deftypefn {Loadable Function} {} psend (@var{value}, @var{connections})\n\
@@ -110,13 +110,13 @@ otherwise the client will hang if @var{value} contains large data\n\
             {
               if (err > 0)
                 {
-                  c_verror ("%s: a previous command at server with index %i caused an error",
+                  _p_error ("%s: a previous command at server with index %i caused an error",
                           fname.c_str (), i + 1);
                   command_errors = true;
                 }
               else // err < 0
                 {
-                  c_verror ("%s: communication error with server with index %i",
+                  _p_error ("%s: communication error with server with index %i",
                           fname.c_str (), i + 1);
                   stream_errors = true;
                 }
@@ -132,8 +132,6 @@ otherwise the client will hang if @var{value} contains large data\n\
         }
     }
 
-  double sid;
-
   // args(0) is const, make copy
   octave_value val = args(0);
 
