@@ -1,7 +1,7 @@
 /*
 
 Copyright (C) 2002 Hayato Fujiwara <h_fujiwara@users.sourceforge.net>
-Copyright (C) 2010-2016 Olaf Till <i7tiol@t-online.de>
+Copyright (C) 2010-2018 Olaf Till <i7tiol@t-online.de>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -21,23 +21,15 @@ along with this program; If not, see <http://www.gnu.org/licenses/>.
 // PKG_ADD: autoload ("pserver", "parallel_interface.oct");
 // PKG_DEL: autoload ("pserver", "parallel_interface.oct", "remove");
 
+#include <octave/oct.h>
+
 #include "config.h"
 
-#include <octave/oct.h>
-#include <octave/symtab.h>
 #include <octave/oct-env.h>
 #include <octave/file-io.h>
 #include <octave/sighandlers.h>
 #include <octave/parse.h>
 #include <octave/cmd-edit.h>
-#ifdef HAVE_OCTAVE_INTERPRETER_H
-// >= octave-4.2
-#include <octave/octave.h>
-#include <octave/interpreter.h>
-#else
-// <= octave-4.0..
-#include <octave/toplev.h>
-#endif
 
 #include <sys/socket.h>
 #include <sys/types.h>
@@ -85,7 +77,7 @@ along with this program; If not, see <http://www.gnu.org/licenses/>.
 static
 int assert_file (std::string &path)
 {
-  file_stat stat (path);
+  OCTAVE__SYS__FILE_STAT stat (path);
 
   if (! stat.is_reg ())
     return -1;
@@ -147,7 +139,7 @@ reval_loop (octave_parallel_stream &cstr)
 
       bool err;
       int p_err;
-      SET_ERR (eval_string (s, false, p_err, 0), err);
+      SET_ERR (OCTAVE__EVAL_STRING (s, false, p_err, 0), err);
       dsprintf ("reval loop, after evaluating string\n");
 
       uint32_t nl = 0;
@@ -396,10 +388,10 @@ the swap device even after shutdown of the application.\n\
     warning ("no TLS used, option 'auth_file' has no effect");
 
   // initialize exit function
-  feval ("__pserver_exit__", octave_value (hostname), 0);
+  OCTAVE__FEVAL ("__pserver_exit__", octave_value (hostname), 0);
 
   int tp;
-  if (tp = fork ())
+  if ((tp = fork ()))
     {
       if (tp == -1)
         error ("could not fork");
@@ -407,7 +399,7 @@ the swap device even after shutdown of the application.\n\
     }
 
   // register exit function
-  feval ("atexit", octave_value ("__pserver_exit__"), 0);
+  OCTAVE__FEVAL ("atexit", octave_value ("__pserver_exit__"), 0);
 
   /* write pidfile and mark for deletion. */
   if (check_and_write_pidfile (pidname.c_str (), getpid ()))
@@ -415,25 +407,25 @@ the swap device even after shutdown of the application.\n\
       std::cerr << "octave: " << hostname.c_str ()
                 << ": can't write pidfile, server possibly already running"
                 << std::endl;
-      clean_up_and_exit (1);
+      exit (1); // clean_up_and_exit (1);
     }
   mark_for_deletion (pidname.c_str ());
   std::cout << pidname.c_str () << std::endl;
 
   // avoid dumping octave_core if killed by a signal
-  feval ("sigterm_dumps_octave_core", octave_value (0), 0);
-  feval ("sighup_dumps_octave_core", octave_value (0), 0);
+  OCTAVE__FEVAL ("sigterm_dumps_octave_core", octave_value (0), 0);
+  OCTAVE__FEVAL ("sighup_dumps_octave_core", octave_value (0), 0);
 
   /* Redirect stdin and stdout to /dev/null. */
   if (! freopen ("/dev/null", "r", stdin))
     {
       perror ("freopen");
-      clean_up_and_exit (1);
+      exit (1); // clean_up_and_exit (1);
     }
   if (! freopen ("/dev/null", "w", stdout))
     {
       perror ("freopen");
-      clean_up_and_exit (1);
+      exit (1); // clean_up_and_exit (1);
     }
 
   std::string errname ("/tmp/octave_error-");
@@ -446,13 +438,13 @@ the swap device even after shutdown of the application.\n\
       if (rename (errname.c_str (), bakname.c_str ()))
         {
           perror ("rename");
-          clean_up_and_exit (1);
+          exit (1); // clean_up_and_exit (1);
         }
     }
   if (! freopen (errname.c_str (), "w", stderr))
     {
       perror ("freopen");
-      clean_up_and_exit (1);
+      exit (1); // clean_up_and_exit (1);
     } 
 
   struct addrinfo *ai, hints;
@@ -465,53 +457,53 @@ the swap device even after shutdown of the application.\n\
   if (getaddrinfo (NULL, "12502", &hints, &ai))
     {
       perror ("getaddrinfo");
-      clean_up_and_exit (1);
+      exit (1); // clean_up_and_exit (1);
     }
 
   int sock = socket (PF_INET, SOCK_STREAM, 0);
   if (sock == -1)
     {
       perror ("socket");
-      clean_up_and_exit (1);
+      exit (1); // clean_up_and_exit (1);
     }
 
   if (bind (sock, ai->ai_addr, ai->ai_addrlen))
     {
       perror ("bind");
-      clean_up_and_exit (1);
+      exit (1); // clean_up_and_exit (1);
     }
 
 
   if (listen (sock, SOMAXCONN))
     {
       perror ("listen");
-      clean_up_and_exit (1);
+      exit (1); // clean_up_and_exit (1);
     }
 
 
   if (getaddrinfo (NULL, "12501", &hints, &ai))
     {
       perror ("getaddrinfo");
-      clean_up_and_exit (1);
+      exit (1); // clean_up_and_exit (1);
     }
 
   int dsock = socket (PF_INET, SOCK_STREAM, 0);
   if (dsock == -1)
     {
       perror ("socket");
-      clean_up_and_exit (1);
+      exit (1); // clean_up_and_exit (1);
     }
 
   if (bind (dsock, ai->ai_addr, ai->ai_addrlen))
     {
       perror ("bind");
-      clean_up_and_exit (1);
+      exit (1); // clean_up_and_exit (1);
     }
 
   if (listen (dsock, SOMAXCONN))
     {
       perror ("listen");
-      clean_up_and_exit (1);
+      exit (1); // clean_up_and_exit (1);
     }
 
   freeaddrinfo (ai);
@@ -525,7 +517,7 @@ the swap device even after shutdown of the application.\n\
       if (asock == -1)
         {
           perror ("accept");
-          clean_up_and_exit (1);
+          exit (1); // clean_up_and_exit (1);
         }
       dsprintf ("%i: accepted command stream\n", server_no);
       /* Normal production daemon.  Fork, and have the child process
@@ -547,12 +539,12 @@ the swap device even after shutdown of the application.\n\
       if ((pid = fork ()) == -1)
         {
           perror ("fork");
-          clean_up_and_exit (1);
+          exit (1); // clean_up_and_exit (1);
         }
       else if (pid == 0) 
         {
           int tp;
-          if (tp = fork ())
+          if ((tp = fork ()))
             {
               if (tp == -1)
                 {
@@ -611,27 +603,34 @@ the swap device even after shutdown of the application.\n\
               // generate credentials
               if (! cafile.length ())
                 {
+#ifdef HAVE_OCTAVE_CONFIG_FCNS
+                  std::string octave_home = octave::config::octave_home ();
+#else
                   extern std::string Voctave_home;
-                  cafile = Voctave_home + file_ops::dir_sep_str () + "share" +
-                    file_ops::dir_sep_str () + "octave" +
-                    file_ops::dir_sep_str () + "parallel-srp-data" +
-                    file_ops::dir_sep_str () + "server" +
-                    file_ops::dir_sep_str () + "passwd";
+                  std::string octave_home = Voctave_home;
+#endif
+                  cafile = octave_home +
+                    OCTAVE__SYS__FILE_OPS::dir_sep_str () + "share" +
+                    OCTAVE__SYS__FILE_OPS::dir_sep_str () + "octave" +
+                    OCTAVE__SYS__FILE_OPS::dir_sep_str () +
+                    "parallel-srp-data" +
+                    OCTAVE__SYS__FILE_OPS::dir_sep_str () + "server" +
+                    OCTAVE__SYS__FILE_OPS::dir_sep_str () + "passwd";
                   if (assert_file (cafile))
                     {
                       octave_value_list f_args (1);
                       f_args(0) = octave_value ("prefix");
                       octave_value_list f_ret;
-                      CHECK_ERROR_EXIT1 (f_ret = feval ("pkg", f_args, 1),
+                      CHECK_ERROR_EXIT1 (f_ret = OCTAVE__FEVAL ("pkg", f_args, 1),
                                          "%s: could not get prefix from pkg",
                                          fname.c_str ());
                       CHECK_ERROR_EXIT1 (cafile = f_ret(0).string_value (),
                                          "%s: could not convert output of pkg ('prefix') to string)",
                                          fname.c_str ());
-                      cafile = cafile + file_ops::dir_sep_str () +
-                        "parallel-srp-data" + file_ops::dir_sep_str () +
-                        file_ops::dir_sep_str () + "server" +
-                        file_ops::dir_sep_str () + "passwd";
+                      cafile = cafile + OCTAVE__SYS__FILE_OPS::dir_sep_str () +
+                        "parallel-srp-data" +
+                        OCTAVE__SYS__FILE_OPS::dir_sep_str () + "server" +
+                        OCTAVE__SYS__FILE_OPS::dir_sep_str () + "passwd";
                       if (assert_file (cafile))
                         {
                           error ("%s: no regular file found at default password file paths",
@@ -804,7 +803,6 @@ the swap device even after shutdown of the application.\n\
               int not_connected = 1;
               for (int j = 0; j < N_CONNECT_RETRIES; j++)
                 {
-                  int32_t result;
                   struct sockaddr_in rem_addr;
                   socklen_t addrlen = sizeof (rem_addr);
                   int adsock = accept (dsock, (sockaddr *) &rem_addr, &addrlen);
@@ -1109,13 +1107,13 @@ the swap device even after shutdown of the application.\n\
           __pwg.__free ();
 
 #ifdef HAVE_OCTAVE_INTERPRETER_H
-          octave::application::the_interpreter () -> interactive (false);
+          OCTAVE__INTERPRETER::the_interpreter () -> interactive (false);
 #else
           interactive = false;
 #endif
 
           // install 'sockets' as Octave variable
-          symbol_table::assign ("sockets", sockets);
+          OCTAVE__INTERPRETER__SYMBOL_TABLE__ASSIGN ("sockets", sockets);
           dsprintf ("'sockets' installed\n");
 
           int cd_ok = octave_env::chdir (directory.c_str ());
@@ -1137,7 +1135,7 @@ the swap device even after shutdown of the application.\n\
 
       // FIXME: forgotten how this is organized in Octave, find it out
       // again and at least make a comment which better explains it.
-      octave_child_list::insert (pid, pserver_child_event_handler);
+      OCTAVE_CHILD_LIST insert (pid, pserver_child_event_handler);
 
       RESTORE_SIGNALS (oset);
 
@@ -1147,5 +1145,7 @@ the swap device even after shutdown of the application.\n\
   // This code is currently not reached since the server parent
   // process can only be killed by a signal.
   close (sock);
-  clean_up_and_exit (1);
+  exit (1); // clean_up_and_exit (1);
+  // Silence compiler warning.
+  exit (0);
 }
