@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2015, 2016 Olaf Till <i7tiol@t-online.de>
+Copyright (C) 2015-2018 Olaf Till <i7tiol@t-online.de>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@ void sensitive_string::fill (int n, bool lock)
 
   if (internally_allocated || locked_length)
     {
-      c_verror ("internal error in filling");
+      _p_error ("internal error in filling");
 
       return;
     }
@@ -44,7 +44,7 @@ void sensitive_string::fill (int n, bool lock)
         {
           if (mlock (val.data, n))
             {
-              c_verror ("could not lock memory pages");
+              _p_error ("could not lock memory pages");
 
               return;
             }
@@ -56,7 +56,7 @@ void sensitive_string::fill (int n, bool lock)
     {
       val.size = 0;
 
-      c_verror ("could not allocate memory");
+      _p_error ("could not allocate memory");
 
       return;
     }
@@ -65,33 +65,41 @@ void sensitive_string::fill (int n, bool lock)
 
   if ((rfd = open ("/dev/random", O_RDONLY)) == -1)
     {
-      c_verror ("could not open /dev/random");
+      _p_error ("could not open /dev/random");
 
       return;
     }
 
-  // reduces each random byte to the 128 characters from 0x20 to 0x9F,
-  // in order to disallow value 0x0 (end of string) without unevenly
-  // redistributing the probability of the allowed values
+  // gnutls nowadays checks if the password is valid UTF8, so many
+  // bytes larger than 0x7F are invalid. Also, bytes < 0x20 are
+  // probably invalid, even if not 0x00. We provide bytes with
+  // probability evenly distributed between 0x20 and 0x7F (96 values).
   for (int i = 0; i < n; i++)
     {
-      if (read (rfd, &(val.data[i]), 1) != 1)
+      do
         {
-          c_verror ("could not read from /dev/random");
+          if (read (rfd, &(val.data[i]), 1) != 1)
+            {
+              _p_error ("could not read from /dev/random");
 
-          err = true;
+              err = true;
 
-          break;
+              break;
+            }
+
+          val.data[i] >>= 1;
         }
+      while (val.data[i] < 0x20);
 
-      val.data[i] = (unsigned char) (((unsigned int) (val.data[i]>>1)) + 0x20);
+      if (err)
+        break;
     }
 
   val.data[n] = '\0';
 
   if (close (rfd))
     {
-      c_verror ("could not close /dev/random");
+      _p_error ("could not close /dev/random");
 
       err = true;
     }
