@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2015, 2016 Olaf Till <i7tiol@t-online.de>
+Copyright (C) 2015-2018 Olaf Till <i7tiol@t-online.de>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -137,7 +137,7 @@ private:
           if (lock)
             {
               if (mlock (val.data, val.size))
-                c_verror ("could not lock memory pages");
+                _p_error ("could not lock memory pages");
               else
                 {
                   valid = true;
@@ -207,7 +207,7 @@ public:
        {
          if (mlock (val.data, val.size))
            {
-             c_verror ("could not lock memory pages");
+             _p_error ("could not lock memory pages");
 
              valid = false;
            }
@@ -306,7 +306,7 @@ public:
   {
     if (gnutls_srp_base64_encode_alloc (data, &val))
       {
-        c_verror ("base64 encoding failed");
+        _p_error ("base64 encoding failed");
 
         valid = false;
       }
@@ -318,7 +318,7 @@ public:
           {
             if (mlock (val.data, val.size))
               {
-                c_verror ("could not lock memory pages");
+                _p_error ("could not lock memory pages");
 
                 valid = false;
               }
